yakumo.nova.v2.floating_ip_dns.Manager

Package yakumo :: Package nova :: Package v2 :: Module floating_ip_dns :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for floating IP DNS entries in Compute API v2

Nested Classes | [hide private]
| resource_class Resource class for floating IP DNS entries in Compute API v2

Instance Methods | [hide private]
None |
create(self, domain=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, scope=`'``__UNDEF__``'`, availability_zone=`'``__UNDEF__``'`) Create a domain | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``compute``'``
| _attr_mapping = ``[``(``'``domain``'``,` `'``domain``'``,` <yakumo.mapper.NoopClass`...``
| _id_attr = ``'``domain``'``
| _json_resource_key = ``'``domain_entry``'``
| _json_resources_key = ``'``domain_entries``'``
| _url_resource_path = ``'``/os-floating-ip-dns``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_hidden_methods`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, domain=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, scope=`'``__UNDEF__``'`, availability_zone=`'``__UNDEF__``'`) | source code
Create a domain Parameters: `domain` (str) - Domain name (str, required) `project` (yakumo.project.Resource) - Project object `scope` (str) - 'public' or 'private' (str) `availability_zone` (str) - Availability zone name (str) Returns: None Resource object (empty) Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('domain',
        'domain',
        <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('project',
        'project',
        <yakumo.mapper.Resource object at 0x7f132fed5c90>),
       ('scope',
        'scope',
      ...